@@ -54,19 +54,19 @@ namespace {
     };
 
     template <class T, class U, class I>
-    std::vector<boost::shared_ptr<BootstrapHelper<T> > > makeHelpers(
+    std::vector<ext::shared_ptr<BootstrapHelper<T> > > makeHelpers(
         Datum iiData[], Size N,
-        const boost::shared_ptr<I> &ii, const Period &observationLag,
+        const ext::shared_ptr<I> &ii, const Period &observationLag,
         const Calendar &calendar,
         const BusinessDayConvention &bdc,
         const DayCounter &dc) {
 
-        std::vector<boost::shared_ptr<BootstrapHelper<T> > > instruments;
+        std::vector<ext::shared_ptr<BootstrapHelper<T> > > instruments;
         for (Size i=0; i<N; i++) {
             Date maturity = iiData[i].date;
-            Handle<Quote> quote(boost::shared_ptr<Quote>(
+            Handle<Quote> quote(ext::shared_ptr<Quote>(
                                 new SimpleQuote(iiData[i].rate/100.0)));
-            boost::shared_ptr<BootstrapHelper<T> > anInstrument(new U(
+            ext::shared_ptr<BootstrapHelper<T> > anInstrument(new U(
                                 quote, observationLag, maturity,
                                 calendar, bdc, dc, ii));
             instruments.push_back(anInstrument);
@@ -96,11 +96,11 @@ namespace {
         DayCounter dcZCIIS,dcNominal;
         std::vector<Date> zciisD;
         std::vector<Rate> zciisR;
-        boost::shared_ptr<UKRPI> ii;
+        ext::shared_ptr<UKRPI> ii;
         Size zciisDataLength;
 
         RelinkableHandle<YieldTermStructure> nominalTS;
-        boost::shared_ptr<ZeroInflationTermStructure> cpiTS;
+        ext::shared_ptr<ZeroInflationTermStructure> cpiTS;
         RelinkableHandle<ZeroInflationTermStructure> hcpi;
 
         // cleanup
@@ -149,7 +149,7 @@ namespace {
             // link from cpi index to cpi TS
             bool interp = false;// this MUST be false because the observation lag is only 2 months
                                 // for ZCIIS; but not for contract if the contract uses a bigger lag.
-            ii = boost::shared_ptr<UKRPI>(new UKRPI(interp, hcpi));
+            ii = ext::make_shared<UKRPI>(interp, hcpi);
             for (Size i=0; i<rpiSchedule.size();i++) {
                 ii->addFixing(rpiSchedule[i], fixData[i], true);// force overwrite in case multiple use
             };
@@ -195,9 +195,9 @@ namespace {
                 nomD.push_back(nominalData[i].date);
                 nomR.push_back(nominalData[i].rate/100.0);
             }
-            boost::shared_ptr<YieldTermStructure> nominal =
-            boost::shared_ptr<InterpolatedZeroCurve<Linear>
-            >(new InterpolatedZeroCurve<Linear>(nomD,nomR,dcNominal));
+            ext::shared_ptr<YieldTermStructure> nominal =
+            ext::make_shared<InterpolatedZeroCurve<Linear>
+            >(nomD,nomR,dcNominal);
 
 
             nominalTS.linkTo(nominal);
@@ -233,7 +233,7 @@ namespace {
             }
 
             // now build the helpers ...
-            std::vector<boost::shared_ptr<BootstrapHelper<ZeroInflationTermStructure> > > helpers =
+            std::vector<ext::shared_ptr<BootstrapHelper<ZeroInflationTermStructure> > > helpers =
             makeHelpers<ZeroInflationTermStructure,ZeroCouponInflationSwapHelper,
             ZeroInflationIndex>(zciisData, zciisDataLength, ii,
                                 observationLag,
@@ -242,13 +242,13 @@ namespace {
             // we can use historical or first ZCIIS for this
             // we know historical is WAY off market-implied, so use market implied flat.
             Rate baseZeroRate = zciisData[0].rate/100.0;
-            boost::shared_ptr<PiecewiseZeroInflationCurve<Linear> > pCPIts(
+            ext::shared_ptr<PiecewiseZeroInflationCurve<Linear> > pCPIts(
                                 new PiecewiseZeroInflationCurve<Linear>(
                                     evaluationDate, calendar, dcZCIIS, observationLag,
                                     ii->frequency(),ii->interpolated(), baseZeroRate,
                                     Handle<YieldTermStructure>(nominalTS), helpers));
             pCPIts->recalculate();
-            cpiTS = boost::dynamic_pointer_cast<ZeroInflationTermStructure>(pCPIts);
+            cpiTS = ext::dynamic_pointer_cast<ZeroInflationTermStructure>(pCPIts);
 
 
             // make sure that the index has the latest zero inflation term structure
@@ -275,7 +275,7 @@ void CPISwapTest::consistency() {
     DayCounter floatDayCount = Actual365Fixed();
     BusinessDayConvention floatPaymentConvention = ModifiedFollowing;
     Natural fixingDays = 0;
-    boost::shared_ptr<IborIndex> floatIndex(new GBPLibor(Period(6,Months),
+    ext::shared_ptr<IborIndex> floatIndex(new GBPLibor(Period(6,Months),
                                                          common.nominalTS));
 
     // fixed x inflation leg
@@ -284,7 +284,7 @@ void CPISwapTest::consistency() {
     DayCounter fixedDayCount = Actual365Fixed();
     BusinessDayConvention fixedPaymentConvention = ModifiedFollowing;
     Calendar fixedPaymentCalendar = UnitedKingdom();
-    boost::shared_ptr<ZeroInflationIndex> fixedIndex = common.ii;
+    ext::shared_ptr<ZeroInflationIndex> fixedIndex = common.ii;
     Period contractObservationLag = common.contractObservationLag;
     CPI::InterpolationType observationInterpolation = common.contractObservationInterpolation;
 
@@ -320,8 +320,8 @@ void CPISwapTest::consistency() {
             floatIndex->addFixing(floatSchedule[i], floatFix[i],true);//true=overwrite
         }
 
-        boost::shared_ptr<CPICoupon>
-        zic = boost::dynamic_pointer_cast<CPICoupon>(zisV.cpiLeg()[i]);
+        ext::shared_ptr<CPICoupon>
+        zic = ext::dynamic_pointer_cast<CPICoupon>(zisV.cpiLeg()[i]);
         if (zic) {
             if (zic->fixingDate() < (common.evaluationDate - Period(1,Months))) {
                 fixedIndex->addFixing(zic->fixingDate(), cpiFix[i],true);
@@ -331,7 +331,7 @@ void CPISwapTest::consistency() {
 
 
     // simple structure so simple pricing engine - most work done by index
-    boost::shared_ptr<DiscountingSwapEngine>
+    ext::shared_ptr<DiscountingSwapEngine>
         dse(new DiscountingSwapEngine(common.nominalTS));
 
     zisV.setPricingEngine(dse);
@@ -345,8 +345,8 @@ void CPISwapTest::consistency() {
             testInfLegNPV += (zisV.leg(0))[i]->amount()*common.nominalTS->discount(zicPayDate);
         }
 
-        boost::shared_ptr<CPICoupon>
-            zicV = boost::dynamic_pointer_cast<CPICoupon>(zisV.cpiLeg()[i]);
+        ext::shared_ptr<CPICoupon>
+            zicV = ext::dynamic_pointer_cast<CPICoupon>(zisV.cpiLeg()[i]);
         if (zicV) {
             Real diff = fabs( zicV->rate() - (fixedRate*(zicV->indexFixing()/baseCPI)) );
             QL_REQUIRE(diff<1e-8,"failed "<<i<<"th coupon reconstruction as "
@@ -370,7 +370,7 @@ void CPISwapTest::consistency() {
                "failed stored consistency value test, ratio = " << diff);
 
     // remove circular refernce
-    common.hcpi.linkTo(boost::shared_ptr<ZeroInflationTermStructure>());
+    common.hcpi.linkTo(ext::shared_ptr<ZeroInflationTermStructure>());
 }
 
 
@@ -392,7 +392,7 @@ void CPISwapTest::zciisconsistency() {
                                   observationLag);
 
     // simple structure so simple pricing engine - most work done by index
-    boost::shared_ptr<DiscountingSwapEngine>
+    ext::shared_ptr<DiscountingSwapEngine>
     dse(new DiscountingSwapEngine(common.nominalTS));
 
     zciis.setPricingEngine(dse);
@@ -411,7 +411,7 @@ void CPISwapTest::zciisconsistency() {
     Date baseDate = startDate - observationLag;
     Real baseCPI = common.ii->fixing(baseDate);
 
-    boost::shared_ptr<IborIndex> dummyFloatIndex;
+    ext::shared_ptr<IborIndex> dummyFloatIndex;
 
     CPISwap cS(stype, floatNominal, subtractInflationNominal, dummySpread, dummyDC, schOneDate,
                paymentConvention, fixingDays, dummyFloatIndex,
@@ -425,7 +425,7 @@ void CPISwapTest::zciisconsistency() {
         QL_REQUIRE(fabs(cS.legNPV(i)-zciis.legNPV(i))<1e-3,"zciis leg does not equal CPISwap leg");
     }
     // remove circular refernce
-    common.hcpi.linkTo(boost::shared_ptr<ZeroInflationTermStructure>());
+    common.hcpi.linkTo(ext::shared_ptr<ZeroInflationTermStructure>());
 }
 
 
@@ -442,7 +442,7 @@ void CPISwapTest::cpibondconsistency() {
     DayCounter floatDayCount = Actual365Fixed();
     BusinessDayConvention floatPaymentConvention = ModifiedFollowing;
     Natural fixingDays = 0;
-    boost::shared_ptr<IborIndex> floatIndex(new GBPLibor(Period(6,Months),
+    ext::shared_ptr<IborIndex> floatIndex(new GBPLibor(Period(6,Months),
                                                          common.nominalTS));
 
     // fixed x inflation leg
@@ -451,7 +451,7 @@ void CPISwapTest::cpibondconsistency() {
     DayCounter fixedDayCount = Actual365Fixed();
     BusinessDayConvention fixedPaymentConvention = ModifiedFollowing;
     Calendar fixedPaymentCalendar = UnitedKingdom();
-    boost::shared_ptr<ZeroInflationIndex> fixedIndex = common.ii;
+    ext::shared_ptr<ZeroInflationIndex> fixedIndex = common.ii;
     Period contractObservationLag = common.contractObservationLag;
     CPI::InterpolationType observationInterpolation = common.contractObservationInterpolation;
 
@@ -486,8 +486,8 @@ void CPISwapTest::cpibondconsistency() {
             floatIndex->addFixing(floatSchedule[i], floatFix[i],true);//true=overwrite
         }
 
-        boost::shared_ptr<CPICoupon>
-        zic = boost::dynamic_pointer_cast<CPICoupon>(zisV.cpiLeg()[i]);
+        ext::shared_ptr<CPICoupon>
+        zic = ext::dynamic_pointer_cast<CPICoupon>(zisV.cpiLeg()[i]);
         if (zic) {
             if (zic->fixingDate() < (common.evaluationDate - Period(1,Months))) {
                 fixedIndex->addFixing(zic->fixingDate(), cpiFix[i],true);
@@ -497,7 +497,7 @@ void CPISwapTest::cpibondconsistency() {
 
 
     // simple structure so simple pricing engine - most work done by index
-    boost::shared_ptr<DiscountingSwapEngine>
+    ext::shared_ptr<DiscountingSwapEngine>
     dse(new DiscountingSwapEngine(common.nominalTS));
 
     zisV.setPricingEngine(dse);
@@ -511,13 +511,13 @@ void CPISwapTest::cpibondconsistency() {
                  observationInterpolation, fixedSchedule,
                  fixedRates, fixedDayCount, fixedPaymentConvention);
 
-    boost::shared_ptr<DiscountingBondEngine>
+    ext::shared_ptr<DiscountingBondEngine>
     dbe(new DiscountingBondEngine(common.nominalTS));
     cpiB.setPricingEngine(dbe);
 
     QL_REQUIRE(fabs(cpiB.NPV() - zisV.legNPV(0))<1e-5,"cpi bond does not equal equivalent cpi swap leg");
     // remove circular refernce
-    common.hcpi.linkTo(boost::shared_ptr<ZeroInflationTermStructure>());
+    common.hcpi.linkTo(ext::shared_ptr<ZeroInflationTermStructure>());
 }
 
 
