@@ -39,8 +39,6 @@
 #endif
 
 #include <boost/timer.hpp>
-#include <boost/shared_ptr.hpp>
-#include <boost/make_shared.hpp>
 #include <boost/thread/thread.hpp>
 #include <boost/interprocess/ipc/message_queue.hpp>
 #include <boost/interprocess/sync/scoped_lock.hpp>
@@ -57,7 +55,6 @@
 #include <sstream>
 #include <utility>
 #include <fstream>
-#include <iostream>
 
 #include <string>
 #include <cstring>
@@ -151,7 +148,7 @@ namespace {
     void output_logstream(
         std::ostream& out, std::streambuf* outBuf, std::stringstream& s) {
 
-        static named_mutex mutex(open_or_create, "namesLogMutexName");
+        static named_mutex mutex(open_or_create, namesLogMutexName);
         scoped_lock<named_mutex> lock(mutex);
 
         out.flush();
@@ -164,7 +161,7 @@ namespace {
         for (std::vector<std::string>::const_iterator iter = tok.begin();
             iter != tok.end(); ++iter) {
             if (iter->length() && iter->compare("Running 1 test case...")) {
-                out << *iter << std::endl;
+                out << *iter  << std::endl;
             }
         }
 
@@ -274,19 +271,6 @@ int main( int argc, char* argv[] )
                     ? tcc.map().find(tcc.testSuiteId())->second
                     : std::list<test_unit_id>();
 
-            std::stringstream logBuf;
-            std::streambuf* const oldBuf = log_stream().rdbuf();
-            log_stream().rdbuf(logBuf.rdbuf());
-
-            for (std::list<test_unit_id>::const_iterator iter = qlRoot.begin();
-                std::distance(qlRoot.begin(), iter) < int(qlRoot.size())-1;
-                ++iter) {
-
-                framework::impl::s_frk_state().execute_test_tree(*iter);
-            }
-            output_logstream(log_stream(), oldBuf, logBuf);
-            log_stream().rdbuf(oldBuf);
-
             // fork worker processes
             boost::thread_group threadGroup;
             for (unsigned i=0; i < nProc; ++i) {
@@ -367,17 +351,6 @@ int main( int argc, char* argv[] )
                     = remoteResults.results;
             }
 
-            if (!qlRoot.empty()) {
-                std::streambuf* const oldBuf = log_stream().rdbuf();
-                log_stream().rdbuf(logBuf.rdbuf());
-
-                const test_unit_id id = qlRoot.back();
-                framework::impl::s_frk_state().execute_test_tree(id);
-
-                output_logstream(log_stream(), oldBuf, logBuf);
-                log_stream().rdbuf(oldBuf);
-            }
-
             TestCaseReportAggregator tca;
             traverse_test_tree(framework::master_test_suite(), tca , true);
 
@@ -427,16 +400,21 @@ int main( int argc, char* argv[] )
             while (!id.terminate) {
                 boost::timer t;
 
-                BOOST_TEST_FOREACH( test_observer*, to,
-                    framework::impl::s_frk_state().m_observers )
-                    framework::impl::s_frk_state().m_aux_em.vexecute(
-                        boost::bind( &test_observer::test_start, to, 1 ) );
+                #if BOOST_VERSION < 106200
+                    BOOST_TEST_FOREACH( test_observer*, to,
+                        framework::impl::s_frk_state().m_observers )
+                        framework::impl::s_frk_state().m_aux_em.vexecute(
+                            boost::bind( &test_observer::test_start, to, 1 ) );
 
-                framework::impl::s_frk_state().execute_test_tree( id.id );
+                    framework::impl::s_frk_state().execute_test_tree( id.id );
 
-                BOOST_TEST_REVERSE_FOREACH( test_observer*, to,
-                    framework::impl::s_frk_state().m_observers )
-                    to->test_finish();
+                    BOOST_TEST_REVERSE_FOREACH( test_observer*, to,
+                        framework::impl::s_frk_state().m_observers )
+                        to->test_finish();
+                #else
+                    // works for BOOST_VERSION > 106100, needed for >106500
+                    framework::run(id.id, false);
+                #endif
 
                 runTimeLogs.push_back(std::make_pair(
                     framework::get(id.id, TUT_ANY).p_name, t.elapsed()));
@@ -446,6 +424,7 @@ int main( int argc, char* argv[] )
                 QualifiedTestResults results
                     = { id.id,
                         boost::unit_test::results_collector.results(id.id) };
+
                 rq.send(&results, sizeof(QualifiedTestResults), 0);
 
                 mq.receive(&id, sizeof(TestCaseId), recvd_size, priority);
