@@ -52,7 +52,6 @@
 #pragma GCC diagnostic pop
 #endif
 
-#include <boost/make_shared.hpp>
 
 using namespace QuantLib;
 using namespace boost::unit_test_framework;
@@ -67,7 +66,7 @@ void RiskNeutralDensityCalculatorTest::testDensityAgainstOptionPrices() {
 
     const Real s0 = 100;
     const Handle<Quote> spot(
-        boost::shared_ptr<SimpleQuote>(new SimpleQuote(s0)));
+        ext::make_shared<SimpleQuote>(s0));
 
     const Rate r = 0.075;
     const Rate q = 0.04;
@@ -77,7 +76,7 @@ void RiskNeutralDensityCalculatorTest::testDensityAgainstOptionPrices() {
 
     const Handle<YieldTermStructure> qTS(flatRate(todaysDate, q, dayCounter));
 
-    const boost::shared_ptr<BlackScholesMertonProcess> bsmProcess(
+    const ext::shared_ptr<BlackScholesMertonProcess> bsmProcess(
         new BlackScholesMertonProcess(
             spot, qTS, rTS,
             Handle<BlackVolTermStructure>(flatVol(v, dayCounter))));
@@ -141,7 +140,7 @@ void RiskNeutralDensityCalculatorTest::testBSMagainstHestonRND() {
 
     const Real s0 = 10;
     const Handle<Quote> spot(
-        boost::shared_ptr<SimpleQuote>(new SimpleQuote(s0)));
+        ext::make_shared<SimpleQuote>(s0));
 
     const Rate r = 0.155;
     const Rate q = 0.0721;
@@ -157,14 +156,14 @@ void RiskNeutralDensityCalculatorTest::testBSMagainstHestonRND() {
 
     const Handle<YieldTermStructure> qTS(flatRate(todaysDate, q, dayCounter));
 
-    const boost::shared_ptr<BlackScholesMertonProcess> bsmProcess(
+    const ext::shared_ptr<BlackScholesMertonProcess> bsmProcess(
         new BlackScholesMertonProcess(
             spot, qTS, rTS,
             Handle<BlackVolTermStructure>(flatVol(v, dayCounter))));
 
     const BSMRNDCalculator bsm(bsmProcess);
     const HestonRNDCalculator heston(
-        boost::make_shared<HestonProcess>(
+        ext::make_shared<HestonProcess>(
             rTS, qTS, spot,
             v0, kappa, theta, sigma, rho), 1e-8);
 
@@ -231,9 +230,9 @@ namespace {
       public:
         DumasParametricVolSurface(
             Real b1, Real b2, Real b3, Real b4, Real b5,
-            const boost::shared_ptr<Quote>& spot,
-            const boost::shared_ptr<YieldTermStructure>& rTS,
-            const boost::shared_ptr<YieldTermStructure>& qTS)
+            const ext::shared_ptr<Quote>& spot,
+            const ext::shared_ptr<YieldTermStructure>& rTS,
+            const ext::shared_ptr<YieldTermStructure>& qTS)
         : BlackVolatilityTermStructure(
               0, NullCalendar(), Following, rTS->dayCounter()),
           b1_(b1), b2_(b2), b3_(b3), b4_(b4), b5_(b5),
@@ -258,17 +257,17 @@ namespace {
 
       private:
         const Real b1_, b2_, b3_, b4_, b5_;
-        const boost::shared_ptr<Quote> spot_;
-        const boost::shared_ptr<YieldTermStructure> rTS_;
-        const boost::shared_ptr<YieldTermStructure> qTS_;
+        const ext::shared_ptr<Quote> spot_;
+        const ext::shared_ptr<YieldTermStructure> rTS_;
+        const ext::shared_ptr<YieldTermStructure> qTS_;
     };
 
-    class ProbWeightedPayoff : public std::unary_function<Real, Real> {
+    class ProbWeightedPayoff {
       public:
         ProbWeightedPayoff(
             Time t,
-            const boost::shared_ptr<Payoff>& payoff,
-            const boost::shared_ptr<RiskNeutralDensityCalculator>& calc)
+            const ext::shared_ptr<Payoff>& payoff,
+            const ext::shared_ptr<RiskNeutralDensityCalculator>& calc)
       : t_(t), payoff_(payoff), calc_(calc) {}
 
         Real operator()(Real x) const {
@@ -277,8 +276,8 @@ namespace {
 
       private:
         const Real t_;
-        const boost::shared_ptr<Payoff> payoff_;
-        const boost::shared_ptr<RiskNeutralDensityCalculator> calc_;
+        const ext::shared_ptr<Payoff> payoff_;
+        const ext::shared_ptr<RiskNeutralDensityCalculator> calc_;
     };
 
     Disposable<std::vector<Time> > adaptiveTimeGrid(
@@ -316,19 +315,19 @@ void RiskNeutralDensityCalculatorTest::testLocalVolatilityRND() {
     const Real s0      = 100;
     const Volatility v = 0.25;
 
-    const boost::shared_ptr<Quote> spot(
-        boost::make_shared<SimpleQuote>(s0));
-    const boost::shared_ptr<YieldTermStructure> rTS(
+    const ext::shared_ptr<Quote> spot(
+        ext::make_shared<SimpleQuote>(s0));
+    const ext::shared_ptr<YieldTermStructure> rTS(
         flatRate(todaysDate, r, dayCounter));
-    const boost::shared_ptr<YieldTermStructure> qTS(
+    const ext::shared_ptr<YieldTermStructure> qTS(
         flatRate(todaysDate, q, dayCounter));
 
-    const boost::shared_ptr<TimeGrid> timeGrid(new TimeGrid(1.0, 101));
+    const ext::shared_ptr<TimeGrid> timeGrid(new TimeGrid(1.0, 101));
 
-    const boost::shared_ptr<LocalVolRNDCalculator> constVolCalc(
+    const ext::shared_ptr<LocalVolRNDCalculator> constVolCalc(
         new LocalVolRNDCalculator(
             spot, rTS, qTS,
-            boost::make_shared<LocalConstantVol>(todaysDate, v, dayCounter),
+            ext::make_shared<LocalConstantVol>(todaysDate, v, dayCounter),
             timeGrid, 201));
 
     const Real rTol = 0.01, atol = 0.005;
@@ -403,18 +402,18 @@ void RiskNeutralDensityCalculatorTest::testLocalVolatilityRND() {
     const Real b4 = -0.02;
     const Real b5 = -0.005;
 
-    const boost::shared_ptr<DumasParametricVolSurface> dumasVolSurface(
+    const ext::shared_ptr<DumasParametricVolSurface> dumasVolSurface(
         new DumasParametricVolSurface(b1, b2, b3, b4, b5, spot, rTS, qTS));
 
-    const boost::shared_ptr<BlackScholesMertonProcess> bsmProcess(
+    const ext::shared_ptr<BlackScholesMertonProcess> bsmProcess(
         new BlackScholesMertonProcess(
             Handle<Quote>(spot),
             Handle<YieldTermStructure>(qTS),
             Handle<YieldTermStructure>(rTS),
             Handle<BlackVolTermStructure>(dumasVolSurface)));
 
-    const boost::shared_ptr<LocalVolTermStructure> localVolSurface
-        = boost::make_shared<NoExceptLocalVolSurface>(
+    const ext::shared_ptr<LocalVolTermStructure> localVolSurface
+        = ext::make_shared<NoExceptLocalVolSurface>(
               Handle<BlackVolTermStructure>(dumasVolSurface),
               Handle<YieldTermStructure>(rTS),
               Handle<YieldTermStructure>(qTS),
@@ -423,10 +422,10 @@ void RiskNeutralDensityCalculatorTest::testLocalVolatilityRND() {
     const std::vector<Time> adaptiveGrid
         = adaptiveTimeGrid(400, 50, 5.0, 3.0);
 
-    const boost::shared_ptr<TimeGrid> dumasTimeGrid(
+    const ext::shared_ptr<TimeGrid> dumasTimeGrid(
         new TimeGrid(adaptiveGrid.begin(), adaptiveGrid.end()));
 
-    const boost::shared_ptr<LocalVolRNDCalculator> dumasVolCalc(
+    const ext::shared_ptr<LocalVolRNDCalculator> dumasVolCalc(
         new LocalVolRNDCalculator(
             spot, rTS, qTS, localVolSurface, dumasTimeGrid, 401, 0.1, 1e-8));
 
@@ -444,17 +443,17 @@ void RiskNeutralDensityCalculatorTest::testLocalVolatilityRND() {
         const Time expiry
             = rTS->dayCounter().yearFraction(todaysDate, maturities[i]);
 
-        const boost::shared_ptr<PricingEngine> engine(
+        const ext::shared_ptr<PricingEngine> engine(
             new FdBlackScholesVanillaEngine(
                 bsmProcess, std::max(Size(51), Size(expiry*101)),
                 201, 0, FdmSchemeDesc::Douglas(), true, b1));
 
-        const boost::shared_ptr<Exercise> exercise(
+        const ext::shared_ptr<Exercise> exercise(
             new EuropeanExercise(maturities[i]));
 
         for (Size k=0; k < LENGTH(strikes); ++k) {
             const Real strike = strikes[k];
-            const boost::shared_ptr<StrikedTypePayoff> payoff(
+            const ext::shared_ptr<StrikedTypePayoff> payoff(
                 new PlainVanillaPayoff(
                     (strike > spot->value()) ? Option::Call : Option::Put
                     , strike));
@@ -607,22 +606,22 @@ void RiskNeutralDensityCalculatorTest::testBlackScholesWithSkew() {
 
     const Handle<YieldTermStructure> rTS(flatRate(todaysDate, r, dc));
     const Handle<YieldTermStructure> qTS(flatRate(todaysDate, q, dc));
-    const Handle<Quote> spot(boost::make_shared<SimpleQuote>(s0));
+    const Handle<Quote> spot(ext::make_shared<SimpleQuote>(s0));
 
-    const boost::shared_ptr<HestonProcess> hestonProcess(
-        boost::make_shared<HestonProcess>(
+    const ext::shared_ptr<HestonProcess> hestonProcess(
+        ext::make_shared<HestonProcess>(
             rTS, qTS, spot, v0, kappa, theta, sigma, rho));
 
     const Handle<BlackVolTermStructure> hestonSurface(
-        boost::make_shared<HestonBlackVolSurface>(
-            Handle<HestonModel>(boost::make_shared<HestonModel>(hestonProcess)),
+        ext::make_shared<HestonBlackVolSurface>(
+            Handle<HestonModel>(ext::make_shared<HestonModel>(hestonProcess)),
             AnalyticHestonEngine::AndersenPiterbarg,
             AnalyticHestonEngine::Integration::discreteTrapezoid(32)));
 
-    const boost::shared_ptr<TimeGrid> timeGrid(new TimeGrid(maturity, 51));
+    const ext::shared_ptr<TimeGrid> timeGrid(new TimeGrid(maturity, 51));
 
-    const boost::shared_ptr<LocalVolTermStructure> localVol(
-        boost::make_shared<NoExceptLocalVolSurface>(
+    const ext::shared_ptr<LocalVolTermStructure> localVol(
+        ext::make_shared<NoExceptLocalVolSurface>(
             hestonSurface, rTS, qTS, spot, std::sqrt(theta)));
 
     const LocalVolRNDCalculator localVolCalc(
@@ -632,7 +631,7 @@ void RiskNeutralDensityCalculatorTest::testBlackScholesWithSkew() {
     const HestonRNDCalculator hestonCalc(hestonProcess);
 
     const GBSMRNDCalculator gbsmCalc(
-        boost::make_shared<BlackScholesMertonProcess>(
+        ext::make_shared<BlackScholesMertonProcess>(
             spot, qTS, rTS, hestonSurface));
 
     const Real strikes[] = { 85, 75, 90, 110, 125, 150 };
