@@ -60,9 +60,16 @@
 #pragma GCC diagnostic pop
 #endif
 
-#include <boost/make_shared.hpp>
 #include <boost/assign/std/vector.hpp>
+
+#if defined(__GNUC__) && !defined(__clang__) && BOOST_VERSION > 106300
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wmaybe-uninitialized"
+#endif
 #include <boost/math/distributions/non_central_chi_squared.hpp>
+#if defined(__GNUC__) && !defined(__clang__) && BOOST_VERSION > 106300
+#pragma GCC diagnostic pop
+#endif
 
 #include <set>
 
@@ -103,7 +110,7 @@ void SquareRootCLVModelTest::testSquareRootCLVVanillaPricing() {
     const Time maturity = dc.yearFraction(todaysDate, maturityDate);
 
     const Real s0 = 100;
-    const Handle<Quote> spot(boost::make_shared<SimpleQuote>(s0));
+    const Handle<Quote> spot(ext::make_shared<SimpleQuote>(s0));
 
     const Rate r = 0.08;
     const Rate q = 0.03;
@@ -114,8 +121,8 @@ void SquareRootCLVModelTest::testSquareRootCLVVanillaPricing() {
     const Handle<BlackVolTermStructure> volTS(flatVol(todaysDate, vol, dc));
     const Real fwd = s0*qTS->discount(maturity)/rTS->discount(maturity);
 
-    const boost::shared_ptr<GeneralizedBlackScholesProcess> bsProcess(
-        boost::make_shared<GeneralizedBlackScholesProcess>(
+    const ext::shared_ptr<GeneralizedBlackScholesProcess> bsProcess(
+        ext::make_shared<GeneralizedBlackScholesProcess>(
             spot, qTS, rTS, volTS));
 
     const Real kappa       = 1.0;
@@ -123,8 +130,8 @@ void SquareRootCLVModelTest::testSquareRootCLVVanillaPricing() {
     const Volatility sigma = 0.2;
     const Real x0          = 0.09;
 
-    const boost::shared_ptr<SquareRootProcess> sqrtProcess(
-        boost::make_shared<SquareRootProcess>(theta, kappa, sigma, x0));
+    const ext::shared_ptr<SquareRootProcess> sqrtProcess(
+        ext::make_shared<SquareRootProcess>(theta, kappa, sigma, x0));
 
     const std::vector<Date> maturityDates(1, maturityDate);
 
@@ -191,7 +198,7 @@ void SquareRootCLVModelTest::testSquareRootCLVMappingFunction() {
     const DayCounter dc = Actual365Fixed();
 
     const Real s0 = 100;
-    const Handle<Quote> spot(boost::make_shared<SimpleQuote>(s0));
+    const Handle<Quote> spot(ext::make_shared<SimpleQuote>(s0));
 
     const Rate r = 0.05;
     const Rate q = 0.02;
@@ -206,11 +213,11 @@ void SquareRootCLVModelTest::testSquareRootCLVMappingFunction() {
     const Real gamma=  0.8;
 
     const Handle<BlackVolTermStructure> sabrVol(
-        boost::make_shared<SABRVolTermStructure>(
+        ext::make_shared<SABRVolTermStructure>(
             alpha, beta, gamma, rho, s0, r, todaysDate, dc));
 
-    const boost::shared_ptr<GeneralizedBlackScholesProcess> bsProcess(
-        boost::make_shared<GeneralizedBlackScholesProcess>(
+    const ext::shared_ptr<GeneralizedBlackScholesProcess> bsProcess(
+        ext::make_shared<GeneralizedBlackScholesProcess>(
             spot, qTS, rTS, sabrVol));
 
     std::vector<Date> calibrationDates(1, todaysDate + Period(1, Weeks));
@@ -224,8 +231,8 @@ void SquareRootCLVModelTest::testSquareRootCLVMappingFunction() {
     const Volatility sigma = 0.2;
     const Real x0          = 0.09;
 
-    const boost::shared_ptr<SquareRootProcess> sqrtProcess(
-        boost::make_shared<SquareRootProcess>(theta, kappa, sigma, x0));
+    const ext::shared_ptr<SquareRootProcess> sqrtProcess(
+        ext::make_shared<SquareRootProcess>(theta, kappa, sigma, x0));
 
     const SquareRootCLVModel model(
         bsProcess, sqrtProcess, calibrationDates, 18, 1-1e-14, 1e-14);
@@ -293,7 +300,7 @@ namespace {
             const Array& strikes,
             const std::vector<Date>& resetDates,
             const std::vector<Date>& maturityDates,
-            const boost::shared_ptr<GeneralizedBlackScholesProcess>& bsProcess,
+            const ext::shared_ptr<GeneralizedBlackScholesProcess>& bsProcess,
             const Array& refVols,
             Size nScenarios = 10000)
       : strikes_      (strikes),
@@ -324,24 +331,24 @@ namespace {
             const Real sigma = params[2];
             const Real x0    = params[3];
 
-            const boost::shared_ptr<SimpleQuote> vol(
-                boost::make_shared<SimpleQuote>(0.1));
+            const ext::shared_ptr<SimpleQuote> vol(
+                ext::make_shared<SimpleQuote>(0.1));
 
             const Handle<YieldTermStructure> rTS(bsProcess_->riskFreeRate());
             const Handle<YieldTermStructure> qTS(bsProcess_->dividendYield());
-            const Handle<Quote> spot(boost::make_shared<SimpleQuote>(
+            const Handle<Quote> spot(ext::make_shared<SimpleQuote>(
                 bsProcess_->x0()));
 
-            const boost::shared_ptr<PricingEngine> fwdEngine(
-                boost::make_shared<ForwardVanillaEngine<AnalyticEuropeanEngine> >(
-                    boost::make_shared<GeneralizedBlackScholesProcess>(
+            const ext::shared_ptr<PricingEngine> fwdEngine(
+                ext::make_shared<ForwardVanillaEngine<AnalyticEuropeanEngine> >(
+                    ext::make_shared<GeneralizedBlackScholesProcess>(
                         spot, qTS, rTS,
                         Handle<BlackVolTermStructure>(
                             flatVol(rTS->referenceDate(), vol,
                                     rTS->dayCounter())))));
 
-            const boost::shared_ptr<SquareRootProcess> sqrtProcess(
-                boost::make_shared<SquareRootProcess>(theta, kappa, sigma, x0));
+            const ext::shared_ptr<SquareRootProcess> sqrtProcess(
+                ext::make_shared<SquareRootProcess>(theta, kappa, sigma, x0));
 
             const SquareRootCLVModel clvSqrtModel(
                 bsProcess_, sqrtProcess, calibrationDates_,
@@ -403,8 +410,8 @@ namespace {
                     }
                 }
 
-                const boost::shared_ptr<Exercise> exercise(
-                    boost::make_shared<EuropeanExercise>(maturityDate));
+                const ext::shared_ptr<Exercise> exercise(
+                    ext::make_shared<EuropeanExercise>(maturityDate));
 
                 const DiscountFactor dF(
                     bsProcess_->riskFreeRate()->discount(maturityDate));
@@ -413,12 +420,12 @@ namespace {
                     const Real strike = strikes_[k];
                     const Real npv = stats[k].mean() * dF;
 
-                    const boost::shared_ptr<StrikedTypePayoff> payoff(
-                        boost::make_shared<PlainVanillaPayoff>(
+                    const ext::shared_ptr<StrikedTypePayoff> payoff(
+                        ext::make_shared<PlainVanillaPayoff>(
                             (strike < 1.0) ? Option::Put : Option::Call, strike));
 
-                    const boost::shared_ptr<ForwardVanillaOption> fwdOption(
-                        boost::make_shared<ForwardVanillaOption>(
+                    const ext::shared_ptr<ForwardVanillaOption> fwdOption(
+                        ext::make_shared<ForwardVanillaOption>(
                             strike, resetDate, payoff, exercise));
 
                     const Volatility implVol =
@@ -441,7 +448,7 @@ namespace {
       private:
         const Array strikes_;
         const std::vector<Date> resetDates_, maturityDates_;
-        const boost::shared_ptr<GeneralizedBlackScholesProcess> bsProcess_;
+        const ext::shared_ptr<GeneralizedBlackScholesProcess> bsProcess_;
         const Array refVols_;
         const Size nScenarios_;
 
@@ -477,7 +484,7 @@ namespace {
 
       public:
         NonZeroConstraint()
-        : Constraint(boost::make_shared<NonZeroConstraint::Impl>()) {}
+        : Constraint(ext::make_shared<NonZeroConstraint::Impl>()) {}
     };
 }
 
@@ -503,21 +510,21 @@ void SquareRootCLVModelTest::testForwardSkew() {
     const Real sigma =  0.3;
     const Real rho   = -0.75;
 
-    const Handle<Quote> spot(boost::make_shared<SimpleQuote>(s0));
+    const Handle<Quote> spot(ext::make_shared<SimpleQuote>(s0));
     const Handle<YieldTermStructure> rTS(flatRate(r, dc));
     const Handle<YieldTermStructure> qTS(flatRate(q, dc));
 
-    const boost::shared_ptr<HestonModel> hestonModel(
-        boost::make_shared<HestonModel>(
-            boost::make_shared<HestonProcess>(
+    const ext::shared_ptr<HestonModel> hestonModel(
+        ext::make_shared<HestonModel>(
+            ext::make_shared<HestonProcess>(
                 rTS, qTS, spot, v0, kappa, theta, sigma, rho)));
 
     const Handle<BlackVolTermStructure> blackVol(
-        boost::make_shared<HestonBlackVolSurface>(
+        ext::make_shared<HestonBlackVolSurface>(
             Handle<HestonModel>(hestonModel)));
 
     const Handle<LocalVolTermStructure> localVol(
-        boost::make_shared<NoExceptLocalVolSurface>(
+        ext::make_shared<NoExceptLocalVolSurface>(
                 blackVol, rTS, qTS, spot, std::sqrt(theta)));
 
     const Real sTheta = 0.389302;
@@ -525,12 +532,12 @@ void SquareRootCLVModelTest::testForwardSkew() {
     const Real sSigma = 0.275368;
     const Real sX0    = 0.466809;
 
-    const boost::shared_ptr<SquareRootProcess> sqrtProcess(
-        boost::make_shared<SquareRootProcess>(
+    const ext::shared_ptr<SquareRootProcess> sqrtProcess(
+        ext::make_shared<SquareRootProcess>(
             sTheta, sKappa, sSigma, sX0));
 
-    const boost::shared_ptr<GeneralizedBlackScholesProcess> bsProcess(
-        boost::make_shared<GeneralizedBlackScholesProcess>(
+    const ext::shared_ptr<GeneralizedBlackScholesProcess> bsProcess(
+        ext::make_shared<GeneralizedBlackScholesProcess>(
             spot, qTS, rTS, blackVol));
 
     std::vector<Date> calibrationDates(1, todaysDate + Period(6, Months));
@@ -555,12 +562,12 @@ void SquareRootCLVModelTest::testForwardSkew() {
 
     const boost::function<Real(Time, Real)> gSqrt = clvSqrtModel.g();
 
-    const boost::shared_ptr<SimpleQuote> vol(
-        boost::make_shared<SimpleQuote>(0.1));
+    const ext::shared_ptr<SimpleQuote> vol(
+        ext::make_shared<SimpleQuote>(0.1));
 
-    const boost::shared_ptr<PricingEngine> fwdEngine(
-        boost::make_shared<ForwardVanillaEngine<AnalyticEuropeanEngine> >(
-            boost::make_shared<GeneralizedBlackScholesProcess>(
+    const ext::shared_ptr<PricingEngine> fwdEngine(
+        ext::make_shared<ForwardVanillaEngine<AnalyticEuropeanEngine> >(
+            ext::make_shared<GeneralizedBlackScholesProcess>(
                 spot, qTS, rTS,
                 Handle<BlackVolTermStructure>(flatVol(todaysDate, vol, dc)))));
 
@@ -601,15 +608,15 @@ void SquareRootCLVModelTest::testForwardSkew() {
     const Real eta = 0.25;
     const Real corr = -0.0;
 
-    const boost::shared_ptr<HestonProcess> hestonProcess4slv(
-        boost::make_shared<HestonProcess>(
+    const ext::shared_ptr<HestonProcess> hestonProcess4slv(
+        ext::make_shared<HestonProcess>(
             rTS, qTS, spot, v0, kappa, theta, eta*sigma, corr));
 
     const Handle<HestonModel> hestonModel4slv(
-        boost::make_shared<HestonModel>(hestonProcess4slv));
+        ext::make_shared<HestonModel>(hestonProcess4slv));
 
     const HestonSLVFokkerPlanckFdmParams logParams = {
-        301, 601, 1000, 30, 2.0, 2,
+        301, 601, 1000, 30, 2.0, 0, 2,
         0.1, 1e-4, 10000,
         1e-5, 1e-5, 0.0000025, 1.0, 0.1, 0.9, 1e-5,
         FdmHestonGreensFct::Gaussian,
@@ -617,14 +624,14 @@ void SquareRootCLVModelTest::testForwardSkew() {
         FdmSchemeDesc::ModifiedCraigSneyd()
     };
 
-    const boost::shared_ptr<LocalVolTermStructure> leverageFctFDM =
+    const ext::shared_ptr<LocalVolTermStructure> leverageFctFDM =
         HestonSLVFDMModel(localVol, hestonModel4slv, endDate, logParams).
             leverageFunction();
 
     //  calibrating to forward volatility dynamics
 
-    const boost::shared_ptr<HestonSLVProcess> fdmSlvProcess(
-        boost::make_shared<HestonSLVProcess>(
+    const ext::shared_ptr<HestonSLVProcess> fdmSlvProcess(
+        ext::make_shared<HestonSLVProcess>(
             hestonProcess4slv, leverageFctFDM));
 
     std::vector<std::vector<GeneralStatistics> > slvStats(
@@ -636,8 +643,8 @@ void SquareRootCLVModelTest::testForwardSkew() {
 
     const Size factors = fdmSlvProcess->factors();
 
-    const boost::shared_ptr<MultiPathGenerator<rsg_type> > pathGen(
-        boost::make_shared<MultiPathGenerator<rsg_type> >(
+    const ext::shared_ptr<MultiPathGenerator<rsg_type> > pathGen(
+        ext::make_shared<MultiPathGenerator<rsg_type> >(
             fdmSlvProcess, grid, rsg_type(factors, grid.size()-1), false));
 
     for (Size k=0; k < nScenarios; ++k) {
@@ -662,19 +669,19 @@ void SquareRootCLVModelTest::testForwardSkew() {
         const Date maturityDate(calibrationDates[i+2]);
         const DiscountFactor df = rTS->discount(maturityDate);
 
-        const boost::shared_ptr<Exercise> exercise(
-            boost::make_shared<EuropeanExercise>(maturityDate));
+        const ext::shared_ptr<Exercise> exercise(
+            ext::make_shared<EuropeanExercise>(maturityDate));
 
         for (Size j=0; j < LENGTH(strikes); ++j) {
             const Real strike = strikes[j];
             const Real npv = slvStats[i][j].mean()*df;
 
-            const boost::shared_ptr<StrikedTypePayoff> payoff(
-                boost::make_shared<PlainVanillaPayoff>(
+            const ext::shared_ptr<StrikedTypePayoff> payoff(
+                ext::make_shared<PlainVanillaPayoff>(
                     (strike < 1.0) ? Option::Put : Option::Call, strike));
 
-            const boost::shared_ptr<ForwardVanillaOption> fwdOption(
-                boost::make_shared<ForwardVanillaOption>(
+            const ext::shared_ptr<ForwardVanillaOption> fwdOption(
+                ext::make_shared<ForwardVanillaOption>(
                     strike, resetDate, payoff, exercise));
 
             const Volatility implVol =
@@ -724,30 +731,30 @@ void SquareRootCLVModelTest::testForwardSkew() {
     const Date maturityDate = todaysDate + Period(1, Years);
     const Time maturityTime = bsProcess->time(maturityDate);
 
-    const boost::shared_ptr<Exercise> europeanExercise(
-        boost::make_shared<EuropeanExercise>(maturityDate));
+    const ext::shared_ptr<Exercise> europeanExercise(
+        ext::make_shared<EuropeanExercise>(maturityDate));
 
     VanillaOption vanillaATMOption(
-        boost::make_shared<PlainVanillaPayoff>(Option::Call,
+        ext::make_shared<PlainVanillaPayoff>(Option::Call,
             s0*qTS->discount(maturityDate)/rTS->discount(maturityDate)),
         europeanExercise);
 
     vanillaATMOption.setPricingEngine(
-        boost::make_shared<AnalyticHestonEngine>(hestonModel));
+        ext::make_shared<AnalyticHestonEngine>(hestonModel));
 
     const Volatility atmVol = vanillaATMOption.impliedVolatility(
         vanillaATMOption.NPV(),
-        boost::make_shared<GeneralizedBlackScholesProcess>(spot, qTS, rTS,
+        ext::make_shared<GeneralizedBlackScholesProcess>(spot, qTS, rTS,
             Handle<BlackVolTermStructure>(flatVol(std::sqrt(theta), dc))));
 
-    const boost::shared_ptr<PricingEngine> analyticEngine(
-        boost::make_shared<AnalyticDoubleBarrierBinaryEngine>(
-            boost::make_shared<GeneralizedBlackScholesProcess>(
+    const ext::shared_ptr<PricingEngine> analyticEngine(
+        ext::make_shared<AnalyticDoubleBarrierBinaryEngine>(
+            ext::make_shared<GeneralizedBlackScholesProcess>(
                 spot, qTS, rTS,
                 Handle<BlackVolTermStructure>(flatVol(atmVol, dc)))));
 
-    const boost::shared_ptr<PricingEngine> fdSLVEngine(
-        boost::make_shared<FdHestonDoubleBarrierEngine>(
+    const ext::shared_ptr<PricingEngine> fdSLVEngine(
+        ext::make_shared<FdHestonDoubleBarrierEngine>(
             hestonModel4slv.currentLink(),
             51, 201, 51, 1,
             FdmSchemeDesc::Hundsdorfer(), leverageFctFDM));
@@ -755,8 +762,8 @@ void SquareRootCLVModelTest::testForwardSkew() {
     const Size n = 16;
     Array barrier_lo(n), barrier_hi(n), bsNPV(n), slvNPV(n);
 
-    const boost::shared_ptr<CashOrNothingPayoff> payoff =
-        boost::make_shared<CashOrNothingPayoff>(Option::Call, 0.0, 1.0);
+    const ext::shared_ptr<CashOrNothingPayoff> payoff =
+        ext::make_shared<CashOrNothingPayoff>(Option::Call, 0.0, 1.0);
 
     for (Size i=0; i < n; ++i) {
         const Real dist = 20.0+5.0*i;
