@@ -46,7 +46,7 @@ using namespace boost::unit_test_framework;
 
 
 namespace {
-    boost::shared_ptr<ExtOUWithJumpsProcess> createKlugeProcess() {
+    ext::shared_ptr<ExtOUWithJumpsProcess> createKlugeProcess() {
         Array x0(2);
         x0[0] = 3.0; x0[1] = 0.0;
 
@@ -56,12 +56,12 @@ namespace {
         const Real speed = 1.0;
         const Real volatility = 2.0;
 
-        boost::shared_ptr<ExtendedOrnsteinUhlenbeckProcess> ouProcess(
+        ext::shared_ptr<ExtendedOrnsteinUhlenbeckProcess> ouProcess(
             new ExtendedOrnsteinUhlenbeckProcess(speed, volatility, x0[0],
                                                  constant<Real, Real>(x0[0])));
-        return boost::shared_ptr<ExtOUWithJumpsProcess>(
-            new ExtOUWithJumpsProcess(ouProcess, x0[1], beta,
-                                      jumpIntensity, eta));
+        return ext::make_shared<ExtOUWithJumpsProcess>(
+            ouProcess, x0[1], beta,
+                                      jumpIntensity, eta);
     }
 }
 
@@ -82,8 +82,8 @@ void SwingOptionTest::testExtendedOrnsteinUhlenbeckProcess() {
 
     boost::function<Real (Real)> f[] 
         = { constant<Real, Real>(level),
-            std::bind1st(std::plus<Real>(), 1.0),
-            std::ptr_fun<Real, Real>(std::sin) }; 
+            add<Real>(1.0),
+            static_cast<Real(*)(Real)>(std::sin) }; 
 
     for (Size n=0; n < LENGTH(f); ++n) {
         ExtendedOrnsteinUhlenbeckProcess refProcess(
@@ -135,10 +135,10 @@ void SwingOptionTest::testFdmExponentialJump1dMesher() {
 
     ExponentialJump1dMesher mesher(dummySteps, beta, jumpIntensity, eta);
 
-    boost::shared_ptr<ExtendedOrnsteinUhlenbeckProcess> ouProcess(
+    ext::shared_ptr<ExtendedOrnsteinUhlenbeckProcess> ouProcess(
         new ExtendedOrnsteinUhlenbeckProcess(1.0, 1.0, x[0],
                                              constant<Real, Real>(1.0)));
-    boost::shared_ptr<ExtOUWithJumpsProcess> jumpProcess(
+    ext::shared_ptr<ExtOUWithJumpsProcess> jumpProcess(
         new ExtOUWithJumpsProcess(ouProcess, x[1], beta, jumpIntensity, eta));
 
     const Time dt = 1.0/(10.0*beta);
@@ -177,7 +177,7 @@ void SwingOptionTest::testExtOUJumpVanillaEngine() {
 
     SavedSettings backup;
 
-    boost::shared_ptr<ExtOUWithJumpsProcess> jumpProcess = createKlugeProcess();
+    ext::shared_ptr<ExtOUWithJumpsProcess> jumpProcess = createKlugeProcess();
 
     const Date today = Date::todaysDate();
     Settings::instance().evaluationDate() = today;
@@ -187,12 +187,12 @@ void SwingOptionTest::testExtOUJumpVanillaEngine() {
     const Time maturity = dc.yearFraction(today, maturityDate);
 
     const Rate irRate = 0.1;
-    boost::shared_ptr<YieldTermStructure> rTS(flatRate(today, irRate, dc));
-    boost::shared_ptr<StrikedTypePayoff> payoff(
+    ext::shared_ptr<YieldTermStructure> rTS(flatRate(today, irRate, dc));
+    ext::shared_ptr<StrikedTypePayoff> payoff(
                                      new PlainVanillaPayoff(Option::Call, 30));
-    boost::shared_ptr<Exercise> exercise(new EuropeanExercise(maturityDate));
+    ext::shared_ptr<Exercise> exercise(new EuropeanExercise(maturityDate));
 
-    boost::shared_ptr<PricingEngine> engine(
+    ext::shared_ptr<PricingEngine> engine(
                  new FdExtOUJumpVanillaEngine(jumpProcess, rTS, 25, 200, 50));
 
     VanillaOption option(payoff, exercise);
@@ -232,26 +232,6 @@ void SwingOptionTest::testExtOUJumpVanillaEngine() {
     }
 }
 
-namespace {
-    class VanillaForwardPayoff : public StrikedTypePayoff {
-      public:
-        VanillaForwardPayoff(Option::Type type, Real strike)
-          : StrikedTypePayoff(type, strike) {}
-
-        std::string name() const { return "ForwardTypePayoff";}
-        Real operator()(Real price) const {
-            switch (type_) {
-              case Option::Call:
-                return price-strike_;
-              case Option::Put:
-                return strike_-price;
-              default:
-                QL_FAIL("unknown/illegal option type");
-            }
-        }
-    };
-}
-
 void SwingOptionTest::testFdBSSwingOption() {
 
     BOOST_TEST_MESSAGE("Testing Black-Scholes vanilla swing option pricing...");
@@ -264,9 +244,9 @@ void SwingOptionTest::testFdBSSwingOption() {
     Date maturityDate = settlementDate + Period(12, Months);
 
     Real strike = 30;
-    boost::shared_ptr<StrikedTypePayoff> payoff(
+    ext::shared_ptr<StrikedTypePayoff> payoff(
         new PlainVanillaPayoff(Option::Put, strike));
-    boost::shared_ptr<StrikedTypePayoff> forward(
+    ext::shared_ptr<StrikedTypePayoff> forward(
         new VanillaForwardPayoff(Option::Put, strike));
 
     std::vector<Date> exerciseDates(1, settlementDate+Period(1, Months));
@@ -274,7 +254,7 @@ void SwingOptionTest::testFdBSSwingOption() {
         exerciseDates.push_back(exerciseDates.back()+Period(1, Months));
     }
 
-    boost::shared_ptr<SwingExercise> swingExercise(
+    ext::shared_ptr<SwingExercise> swingExercise(
                                             new SwingExercise(exerciseDates));
 
     Handle<YieldTermStructure> riskFreeTS(flatRate(0.14, dayCounter));
@@ -282,15 +262,15 @@ void SwingOptionTest::testFdBSSwingOption() {
     Handle<BlackVolTermStructure> volTS(
                                     flatVol(settlementDate, 0.4, dayCounter));
 
-    Handle<Quote> s0(boost::shared_ptr<Quote>(new SimpleQuote(30.0)));
+    Handle<Quote> s0(ext::shared_ptr<Quote>(new SimpleQuote(30.0)));
 
-    boost::shared_ptr<BlackScholesMertonProcess> process(
+    ext::shared_ptr<BlackScholesMertonProcess> process(
             new BlackScholesMertonProcess(s0, dividendTS, riskFreeTS, volTS));
-    boost::shared_ptr<PricingEngine> engine(
+    ext::shared_ptr<PricingEngine> engine(
                                 new FdSimpleBSSwingEngine(process, 50, 200));
     
     VanillaOption bermudanOption(payoff, swingExercise);
-    bermudanOption.setPricingEngine(boost::shared_ptr<PricingEngine>(
+    bermudanOption.setPricingEngine(ext::shared_ptr<PricingEngine>(
                           new FdBlackScholesVanillaEngine(process, 50, 200)));
     const Real bermudanOptionPrices = bermudanOption.NPV();
     
@@ -313,10 +293,10 @@ void SwingOptionTest::testFdBSSwingOption() {
         
         Real lowerBound = 0.0;
         for (Size j=exerciseDates.size()-i-1; j < exerciseDates.size(); ++j) {
-            VanillaOption europeanOption(payoff, boost::shared_ptr<Exercise>(
+            VanillaOption europeanOption(payoff, ext::shared_ptr<Exercise>(
                                      new EuropeanExercise(exerciseDates[j])));
             europeanOption.setPricingEngine(
-                boost::shared_ptr<PricingEngine>(
+                ext::shared_ptr<PricingEngine>(
                                           new AnalyticEuropeanEngine(process)));
             lowerBound += europeanOption.NPV();
         }
@@ -343,16 +323,16 @@ void SwingOptionTest::testExtOUJumpSwingOption() {
     Date maturityDate = settlementDate + Period(12, Months);
 
     Real strike = 30;
-    boost::shared_ptr<StrikedTypePayoff> payoff(
+    ext::shared_ptr<StrikedTypePayoff> payoff(
         new PlainVanillaPayoff(Option::Put, strike));
-    boost::shared_ptr<StrikedTypePayoff> forward(
+    ext::shared_ptr<StrikedTypePayoff> forward(
         new VanillaForwardPayoff(Option::Put, strike));
 
     std::vector<Date> exerciseDates(1, settlementDate+Period(1, Months));
     while (exerciseDates.back() < maturityDate) {
         exerciseDates.push_back(exerciseDates.back()+Period(1, Months));
     }
-    boost::shared_ptr<SwingExercise> swingExercise(
+    ext::shared_ptr<SwingExercise> swingExercise(
                                             new SwingExercise(exerciseDates));
 
     std::vector<Time> exerciseTimes(exerciseDates.size());
@@ -367,16 +347,16 @@ void SwingOptionTest::testExtOUJumpSwingOption() {
         exerciseIndex[i] = grid.closestIndex(exerciseTimes[i]);
     }
 
-    boost::shared_ptr<ExtOUWithJumpsProcess> jumpProcess = createKlugeProcess();
+    ext::shared_ptr<ExtOUWithJumpsProcess> jumpProcess = createKlugeProcess();
 
     const Rate irRate = 0.1;
-    boost::shared_ptr<YieldTermStructure> rTS(
+    ext::shared_ptr<YieldTermStructure> rTS(
                                 flatRate(settlementDate, irRate, dayCounter));
 
-    boost::shared_ptr<PricingEngine> swingEngine(
+    ext::shared_ptr<PricingEngine> swingEngine(
                 new FdSimpleExtOUJumpSwingEngine(jumpProcess, rTS, 25, 50, 25));
 
-    boost::shared_ptr<PricingEngine> vanillaEngine(
+    ext::shared_ptr<PricingEngine> vanillaEngine(
                 new FdExtOUJumpVanillaEngine(jumpProcess, rTS, 25, 50, 25));
 
     VanillaOption bermudanOption(payoff, swingExercise);
@@ -409,10 +389,10 @@ void SwingOptionTest::testExtOUJumpSwingOption() {
 
         Real lowerBound = 0.0;
         for (Size j=exerciseDates.size()-i-1; j < exerciseDates.size(); ++j) {
-            VanillaOption europeanOption(payoff, boost::shared_ptr<Exercise>(
+            VanillaOption europeanOption(payoff, ext::shared_ptr<Exercise>(
                                      new EuropeanExercise(exerciseDates[j])));
             europeanOption.setPricingEngine(
-                boost::shared_ptr<PricingEngine>(vanillaEngine));
+                ext::shared_ptr<PricingEngine>(vanillaEngine));
             lowerBound += europeanOption.NPV();
         }
 
